# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`cfssl`](#cfssl): Install and configure CFSSL, serve process and CRL generation.
* [`cfssl::ca::gencrls`](#cfsslcagencrls): Creates services to generate CRL for a list of CA
* [`cfssl::ca::intermediates`](#cfsslcaintermediates): Creates `cfssl::ca::intermediate` defined types.
* [`cfssl::ca::root`](#cfsslcaroot): Init a selfsigned root authority
* [`cfssl::params`](#cfsslparams): A short summary of the purpose of this class

#### Private Classes

* `cfssl::goose`: Installs Goose, a database migration tool used by CFSSL

### Defined types

#### Public Defined types

* [`cfssl::ca::intermediate`](#cfsslcaintermediate): Creates an intermediate authority signed by root authority

#### Private Defined types

* `cfssl::ca::gencrl`: Creates a service to generate CRL for a CA

Creates a service to generate CRL for a CA

### Data types

* [`Cfssl::Authkey`](#cfsslauthkey): Struct representing authentication key used by CFSSL serve during sign requests
* [`Cfssl::Ca::Key`](#cfsslcakey): Cryptographic algorithm used for creating key pairs.
* [`Cfssl::Serveconfig`](#cfsslserveconfig): Struct representing CFSSL serve configuration
* [`Cfssl::Signing::Profile`](#cfsslsigningprofile): Struct describing a profile in CFSSL serve config file.
* [`Cfssl::Usage`](#cfsslusage): List of usages accepted by CFSSL for X509 certificat

## Classes

### <a name="cfssl"></a>`cfssl`

Install and configure CFSSL, serve process and CRL generation.

#### Examples

##### 

```puppet
class { 'cfssl':
  rootca_manifest => {
    cn      => 'MYEXEMPLE ROOT CA',
    subject => {
      'C' => 'FR',
      'L' => 'MONTPELLIER',
      'O' => 'MYEXEMPLE ORG',
    },
  },
  intermediatesca => {
    'MYEXEMPLE INTERMDIATE CA' => {
      subject => {
        'C' => 'FR',
        'L' => 'MONTPELLIER',
        'O' => 'MYEXEMPLE ORG',
      },
    },
  },
  serve_ca   => 'MYEXEMPLE INTERMDIATE CA',
  crl_manage => true,
}
```

#### Parameters

The following parameters are available in the `cfssl` class:

* [`downloadurl`](#downloadurl)
* [`version`](#version)
* [`downloadchecksum`](#downloadchecksum)
* [`checksum_type`](#checksum_type)
* [`sysuser`](#sysuser)
* [`sysgroup`](#sysgroup)
* [`binding_ip`](#binding_ip)
* [`port`](#port)
* [`log_level`](#log_level)
* [`logdir`](#logdir)
* [`dbname`](#dbname)
* [`dbuser`](#dbuser)
* [`dbpassword`](#dbpassword)
* [`confdir`](#confdir)
* [`binpath`](#binpath)
* [`rootca_manifest`](#rootca_manifest)
* [`intermediatesca`](#intermediatesca)
* [`serve_config`](#serve_config)
* [`crl_manage`](#crl_manage)
* [`crldir`](#crldir)
* [`crl_expiry`](#crl_expiry)
* [`crl_gentimer`](#crl_gentimer)
* [`crl_extension`](#crl_extension)
* [`serve_ca`](#serve_ca)

##### <a name="downloadurl"></a>`downloadurl`

Data type: `Stdlib::HTTPSUrl`

CFSSL download URL

Default value: `'https://github.com/cloudflare/cfssl/releases/download'`

##### <a name="version"></a>`version`

Data type: `String[1]`

Downloaded version of CFSSL binary

Default value: `'1.6.3'`

##### <a name="downloadchecksum"></a>`downloadchecksum`

Data type: `String[1]`

Checksum of CFSSL binary

Default value: `'16b42bfc592dc4d0ba1e51304f466cae7257edec13743384caf4106195ab6047'`

##### <a name="checksum_type"></a>`checksum_type`

Data type: `Enum['md5', 'sha1', 'sha2','sha256', 'sha384', 'sha512']`

Type of checksum used

Default value: `'sha256'`

##### <a name="sysuser"></a>`sysuser`

Data type: `String[1]`

Operating system user account owner of CFSSL files

Default value: `'cfssl'`

##### <a name="sysgroup"></a>`sysgroup`

Data type: `String[1]`

Operating system group owner of CFSSL files

Default value: `'cfssl'`

##### <a name="binding_ip"></a>`binding_ip`

Data type: `Stdlib::IP::Address`

IP adresse binded by CFSSL serve process.

Default value: `'127.0.0.1'`

##### <a name="port"></a>`port`

Data type: `Stdlib::Port`

The port used by CFSSL serve process.

Default value: `8080`

##### <a name="log_level"></a>`log_level`

Data type: `Enum['0','1','2','3','4']`

The loglevel defined for CFSSL serve process.

Default value: `'1'`

##### <a name="logdir"></a>`logdir`

Data type: `Stdlib::Absolutepath`

The directory where log are written.

Default value: `'/var/log/cfssl'`

##### <a name="dbname"></a>`dbname`

Data type: `String[1]`

The name of database used by CFSSL.

Default value: `'db_cfssl'`

##### <a name="dbuser"></a>`dbuser`

Data type: `String[1]`

A Postgresql role used by CFSSL to connect the database.

Default value: `'u_cfssl'`

##### <a name="dbpassword"></a>`dbpassword`

Data type: `Variant[String[1], Sensitive[String]]`

A password of the dbuser.

Default value: `('changeme')`

##### <a name="confdir"></a>`confdir`

Data type: `Stdlib::Absolutepath`

The directory where configurations are written.

Default value: `'/etc/cfssl'`

##### <a name="binpath"></a>`binpath`

Data type: `Stdlib::Absolutepath`

The path when CFSSL binaries are.

Default value: `'/usr/local/bin'`

##### <a name="rootca_manifest"></a>`rootca_manifest`

Data type: `Hash`

Manifest defining the root autority.

Default value: `{ cn => 'EXEMPLE ROOT CA', subject => { 'C' => 'FR', 'L' => 'MONTPELLIER', 'O' => 'EXEMPLE ORG', } }`

##### <a name="intermediatesca"></a>`intermediatesca`

Data type: `Hash`

Manifests defining intermediat autorities signed by root autority.

Default value: `{}`

##### <a name="serve_config"></a>`serve_config`

Data type: `Cfssl::Serveconfig`

The configuration of CFSSL serve process.

Default value: `{ signing => { 'default' => { expiry => '1h', usages => ['client auth'] } } }`

##### <a name="crl_manage"></a>`crl_manage`

Data type: `Boolean`

If true a CRL file is generated from the served autority.

Default value: ``false``

##### <a name="crldir"></a>`crldir`

Data type: `Stdlib::Absolutepath`

A directory where the CRL file is written.

Default value: `'/var/cfssl'`

##### <a name="crl_expiry"></a>`crl_expiry`

Data type: `Integer`

A value, in seconds, after which the CRL should expire from the moment of the request

Default value: `604800`

##### <a name="crl_gentimer"></a>`crl_gentimer`

Data type: `String[1]`

Systemd timer https://www.freedesktop.org/software/systemd/man/systemd.time.html

Default value: `'*:00:00'`

##### <a name="crl_extension"></a>`crl_extension`

Data type: `String[1]`

The filename extension suffix used form generated CRL.

Default value: `'pem'`

##### <a name="serve_ca"></a>`serve_ca`

Data type: `Optional[String[1]]`

The Certificate authority served with CFSSL serve

Default value: ``undef``

### <a name="cfsslcagencrls"></a>`cfssl::ca::gencrls`

Creates services to generate CRL for a list of CA

#### Examples

##### 

```puppet
class { 'cfssl::ca::gencrls':
  authorities => [
    'MYEXEMPLE ROOT CA',
    'MYEXEMPLE INTERMDIATE CA',
  ],
}
```

#### Parameters

The following parameters are available in the `cfssl::ca::gencrls` class:

* [`authorities`](#authorities)

##### <a name="authorities"></a>`authorities`

Data type: `Array[String]`

A list of authority CN's, already defined.

Default value: `[]`

### <a name="cfsslcaintermediates"></a>`cfssl::ca::intermediates`

Creates `cfssl::ca::intermediate` defined types.

#### Examples

##### 

```puppet
class { 'cfssl::ca::intermediates':
  'MYEXEMPLE INTERMDIATE CA' => {
    subject => {
      'C' => 'FR',
      'L' => 'MONTPELLIER',
      'O' => 'MYEXEMPLE ORG',
    },
    key     => {
      algo => 'ecdsa',
      size => 256,
    },
  },
}
```

#### Parameters

The following parameters are available in the `cfssl::ca::intermediates` class:

* [`intermediates`](#intermediates)

##### <a name="intermediates"></a>`intermediates`

Data type: `Hash`

A hash wherethe key is  the common name and the value represents a hash
of `cfssl::ca::intermediate` defined type's parameters.

Default value: `{}`

### <a name="cfsslcaroot"></a>`cfssl::ca::root`

Init a selfsigned root authority

#### Examples

##### 

```puppet
class { 'cfssl::ca::root':
  cn      => 'MYEXEMPLE ROOT CA',
  subject => {
    'C' => 'FR',
    'L' => 'MONTPELLIER',
    'O' => 'MYEXEMPLE ORG',
  },
}
```

#### Parameters

The following parameters are available in the `cfssl::ca::root` class:

* [`subject`](#subject)
* [`cn`](#cn)
* [`expiry`](#expiry)
* [`key`](#key)

##### <a name="subject"></a>`subject`

Data type: `Hash`

Hash like Subject in X509 that identifies the entity associated

##### <a name="cn"></a>`cn`

Data type: `String[1]`

Common name of authority

##### <a name="expiry"></a>`expiry`

Data type: `String[1]`

Duration of authority

Default value: `'43800h'`

##### <a name="key"></a>`key`

Data type: `Cfssl::Ca::Key`

Cryptographic algorithm used for creating key pairs.

Default value: `{ algo => 'rsa', size => 2048 }`

### <a name="cfsslparams"></a>`cfssl::params`

A description of what this class does

#### Examples

##### 

```puppet
include cfssl::params
```

## Defined types

### <a name="cfsslcaintermediate"></a>`cfssl::ca::intermediate`

Creates an intermediate authority signed by root authority

#### Examples

##### 

```puppet
cfssl::ca::intermediate { 'MYEXEMPLE INTERMDIATE CA':
  subject => {
    'C'   => 'FR',
    'L'   => 'MONTPELLIER',
    'O'   => 'MYEXEMPLE ORG',
  },
}
```

#### Parameters

The following parameters are available in the `cfssl::ca::intermediate` defined type:

* [`subject`](#subject)
* [`expiry`](#expiry)
* [`key`](#key)
* [`crl_url`](#crl_url)
* [`ocsp_url`](#ocsp_url)

##### <a name="subject"></a>`subject`

Data type: `Hash`

Hash like Subject in X509 that identifies the entity associated

Default value: `{ 'C' => 'FR', 'L' => 'MONTPELLIER', 'O' => 'EXEMPLE ORG', }`

##### <a name="expiry"></a>`expiry`

Data type: `String[1]`

Duration of authority

Default value: `'26280h'`

##### <a name="key"></a>`key`

Data type: `Cfssl::Ca::Key`

Cryptographic algorithm used for creating key pairs.

Default value: `{ algo => 'rsa', size => 2048 }`

##### <a name="crl_url"></a>`crl_url`

Data type: `Optional[Stdlib::HTTPUrl]`

The CRL url of the Root CA that issued intermediate CA.

Default value: ``undef``

##### <a name="ocsp_url"></a>`ocsp_url`

Data type: `Optional[Stdlib::HTTPUrl]`

The OCSP responder of the Root CA that issued intermediate CA.

Default value: ``undef``

## Data types

### <a name="cfsslauthkey"></a>`Cfssl::Authkey`

Struct representing authentication key used by CFSSL serve during sign requests

Alias of

```puppet
Struct[{
    type => Enum['standard'],
    key  => String[1],
}]
```

### <a name="cfsslcakey"></a>`Cfssl::Ca::Key`

Cryptographic algorithm used for creating key pairs.

Alias of

```puppet
Struct[{
    algo => Enum['rsa','ecdsa'],
    size => Integer,
}]
```

### <a name="cfsslserveconfig"></a>`Cfssl::Serveconfig`

Struct representing CFSSL serve configuration

Alias of

```puppet
Struct[{
    auth_keys => Optional[Hash[String,Cfssl::Authkey]],
    signing   => Struct[{
        'default' => Cfssl::Signing::Profile,
        profiles  => Optional[Hash[String,Cfssl::Signing::Profile]],
    }],
}]
```

### <a name="cfsslsigningprofile"></a>`Cfssl::Signing::Profile`

Struct describing a profile in CFSSL serve config file.

Alias of

```puppet
Struct[{
    expiry         => String[1],
    usages         => Array[Cfssl::Usage],
    crl_url        => Optional[Stdlib::HTTPUrl],
    ocsp_url       => Optional[Stdlib::HTTPUrl],
    not_before     => Optional[String[1]],
    not_after      => Optional[String[1]],
    name_whitelist => Optional[String[1]],
    auth_key       => Optional[String[1]],
}]
```

### <a name="cfsslusage"></a>`Cfssl::Usage`

List of usages accepted by CFSSL for X509 certificat

Alias of

```puppet
Enum['signing', 'digital signature', 'content commitment', 'key encipherment', 'key agreement', 'data encipherment', 'cert sign', 'crl sign', 'encipher only', 'decipher only', 'any', 'server auth', 'client auth', 'code signing', 'email protection', 's/mime', 'ipsec end system', 'ipsec tunnel', 'ipsec user', 'timestamping', 'ocsp signing', 'microsoft sgc', 'netscape sgc']
```

